@@ -45,6 +45,7 @@ extern void select_all_icons(Scrn *i);
 extern void mod_menuselect(struct module *, int, int, int);
 extern void setfocus(Window);
 extern void flushmodules();
+extern void wberror(Scrn *, char *);
 
 Scrn *mbdclick=NULL, *mbdscr=NULL;
 
@@ -113,7 +114,7 @@ void spawn(const char *cmd)
       waitpid (pid, &status, 0);
   }
 #else
-  system(line);
+  (void)! system(line);
 #endif
 #ifndef HAVE_ALLOCA
     free(line);
@@ -366,23 +367,35 @@ void createmenubar()
 
   scr->firstmenu = NULL;
   attr.override_redirect=True;
-  attr.background_pixel=scr->dri.dri_Pens[BARBLOCKPEN];
-  scr->menubar=XCreateWindow(dpy, scr->back, 0, 0, scr->width, scr->bh, 0,
-			     CopyFromParent,
-			     InputOutput, CopyFromParent,
-			     CWOverrideRedirect|CWBackPixel,
-			     &attr);
+  if (scr->deftitle) {
+    attr.background_pixel=scr->dri.dri_Pens[BARBLOCKPEN];
+    scr->menubar=XCreateWindow(dpy, scr->back, 0, 0, scr->width, scr->bh, 0,
+			       CopyFromParent,
+			       InputOutput, CopyFromParent,
+			       CWOverrideRedirect|CWBackPixel,
+			       &attr);
+    scr->menubarparent=XCreateWindow(dpy, scr->menubar, 0, 0, scr->width,
+				     scr->bh-1, 0,
+				     CopyFromParent, InputOutput, CopyFromParent,
+				     CWOverrideRedirect|CWBackPixel, &attr);
+    attr.background_pixel=scr->dri.dri_Pens[BACKGROUNDPEN];
+    scr->menubardepth=XCreateWindow(dpy, scr->menubar, scr->width-23,
+				    0, 23, scr->bh, 0,
+				    CopyFromParent, InputOutput, CopyFromParent,
+				    CWOverrideRedirect|CWBackPixel, &attr);
+  } else {
+    scr->menubar=XCreateWindow(dpy, scr->back, 0, 0, scr->width, scr->bh, 0, 0,
+			       InputOnly, CopyFromParent,
+			       CWOverrideRedirect, &attr);
+    scr->menubarparent=None;
+    scr->menubardepth=XCreateWindow(dpy, scr->menubar, scr->width-23,
+				    0, 23, scr->bh, 0, 0,
+				    InputOnly, CopyFromParent,
+				    CWOverrideRedirect, &attr);
+  }
   XSaveContext(dpy, scr->menubar, screen_context, (XPointer)scr);
-  scr->menubarparent=XCreateWindow(dpy, scr->menubar, 0, 0, scr->width,
-				   scr->bh-1, 0,
-				   CopyFromParent, InputOutput, CopyFromParent,
-				   CWOverrideRedirect|CWBackPixel, &attr);
-  XSaveContext(dpy, scr->menubarparent, screen_context, (XPointer)scr);
-  attr.background_pixel=scr->dri.dri_Pens[BACKGROUNDPEN];
-  scr->menubardepth=XCreateWindow(dpy, scr->menubar, scr->width-23,
-				  0, 23, scr->bh, 0,
-				  CopyFromParent, InputOutput, CopyFromParent,
-				  CWOverrideRedirect|CWBackPixel, &attr);
+  if (scr->menubarparent)
+    XSaveContext(dpy, scr->menubarparent, screen_context, (XPointer)scr);
   XSaveContext(dpy, scr->menubardepth, screen_context, (XPointer)scr);
   scr->disabled_stipple=XCreatePixmap(dpy, scr->back, 6, 2, 1);
   gc=XCreateGC(dpy, scr->disabled_stipple, 0, NULL);
@@ -392,11 +405,14 @@ void createmenubar()
   XDrawPoint(dpy, scr->disabled_stipple, gc, 0, 0);
   XDrawPoint(dpy, scr->disabled_stipple, gc, 3, 1);
   XFreeGC(dpy, gc);
-  scr->menubargc=XCreateGC(dpy, scr->menubar, 0, NULL); 
+  if (scr->deftitle) {
+    scr->menubargc=XCreateGC(dpy, scr->menubar, 0, NULL); 
 #ifndef USE_FONTSETS
-  XSetFont(dpy, scr->menubargc, scr->dri.dri_Font->fid);
+    XSetFont(dpy, scr->menubargc, scr->dri.dri_Font->fid);
 #endif
-  XSetBackground(dpy, scr->menubargc, scr->dri.dri_Pens[BARBLOCKPEN]);
+    XSetBackground(dpy, scr->menubargc, scr->dri.dri_Pens[BARBLOCKPEN]);
+  } else
+    scr->menubargc = NULL;
   XSelectInput(dpy, scr->menubar, ExposureMask|ButtonPressMask|ButtonReleaseMask);
   XSelectInput(dpy, scr->menubardepth, ExposureMask|ButtonPressMask|
 	       ButtonReleaseMask|EnterWindowMask|LeaveWindowMask);
@@ -407,6 +423,8 @@ void createmenubar()
   scr->checkmarkspace=4+scr->dri.dri_Ascent;
   scr->subspace=scr->hotkeyspace-scr->dri.dri_Ascent;
   scr->menuleft=4;
+  if (!scr->menubarparent)
+    return;
   m=add_menu("Workbench", 0);
   add_item(m,"Backdrop",'B',CHECKIT|CHECKED|DISABLED);
   add_item(m,"Execute Command...",'E',0);
@@ -487,7 +505,7 @@ void redrawmenubar(Window w)
   struct Menu *m;
   struct Item *item;
 
-  if(!w)
+  if(!w || !scr->menubargc)
     return;
   if(w==scr->menubar) {
     XSetForeground(dpy, scr->menubargc, scr->dri.dri_Pens[BARDETAILPEN]);
